Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AttrToStat ¶
AttrToStat converts a protobuf Attr back to a FUSE Stat_t.
func NanoToTimespec ¶
NanoToTimespec converts nanoseconds since Unix epoch to a fuse.Timespec.
Types ¶
type FileAction ¶
type FileAction int
FileAction maps local FS events
const ( Unknown FileAction = iota AddDir AddFile RemoveDir RemoveFile EditDir EditFile RenameFile RenameDir )
type FileEvent ¶
type FileEvent struct {
Path string // relative path in the FS (new path for renames)
OldPath string // for renames: the source path
Action FileAction // type of event
Attr *keibidrop.Attr // file attributes (from Stat_t)
}
FileEvent represents a filesystem change
type FileStreamProvider ¶
type FileStreamProvider interface {
OpenRemoteFile(ctx context.Context, inode uint64, path string) (RemoteFileStream, error)
// StreamFile starts a push-based download: server sends all chunks
// from startOffset to EOF without per-chunk round-trips.
StreamFile(ctx context.Context, path string, startOffset uint64) (StreamFileReceiver, error)
}
FileStreamProvider is a factory for RemoteFileStream and StreamFile.
type RemoteFileStream ¶
Click to show internal directories.
Click to hide internal directories.